@@ -2,20 +2,20 @@ from neispy.sync import SyncNeispy
 
 
 def test_all(client: SyncNeispy):
-    scinfo = client.schoolInfo(SCHUL_NM="인천석천초등학교")
+    scinfo = client.schoolInfo(SCHUL_NM="인천동방초등학교")
     AE = scinfo[0].ATPT_OFCDC_SC_CODE  # 교육청코드
     SE = scinfo[0].SD_SCHUL_CODE  # 학교코드
 
-    # 학교코드와 교육청 코드로 2019년 1월 22일의 급식 정보 요청
-    scmeal = client.mealServiceDietInfo(AE, SE, MLSV_YMD="20190122")
+    # 학교코드와 교육청 코드로 2022년 5월 23일의 급식 정보 요청
+    scmeal = client.mealServiceDietInfo(AE, SE, MLSV_YMD="20220523")
     meal = scmeal[0].DDISH_NM.replace("<br/>", "\n")  # 줄바꿈으로 만든뒤 출력
 
-    # 학교코드와 교육청 코드로 2019년 3월 7일날 학사일정 요청
-    scschedule = client.SchoolSchedule(AE, SE, AA_YMD=20201002)
+    # 학교코드와 교육청 코드로 2022년 6월 1일날 학사일정 요청
+    scschedule = client.SchoolSchedule(AE, SE, AA_YMD=20220601)
     schedule = scschedule[0].EVENT_NM  # 학사일정명 가져옴
 
-    # 학교코드와 교육청 코드로 초등학교의 2020년 1월 22일의 시간표가져옴
-    sctimetable = client.elsTimetable(AE, SE, 2019, 2, 20200122, "1", "1")
+    # 학교코드와 교육청 코드로 초등학교의 2022년 1월 22일의 시간표가져옴
+    sctimetable = client.elsTimetable(AE, SE, 2022, 1, 20220523, "1", "1")
     timetable = [i.ITRT_CNTNT for i in sctimetable]  # 리스트로 만듬
 
     academyinfo = client.acaInsTiInfo(AE)  # 교육청 코드로 학원및 교습소 정보 요청
